package com.isu.gaswellwatch.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.isu.gaswellwatch.config.SnowflakeConfig;
import com.isu.gaswellwatch.service.CompanyService;
import com.isu.gaswellwatch.dao.CompanyDao;
import com.isu.gaswellwatch.dto.*;
import com.isu.gaswellwatch.entity.Company;
import com.isu.gaswellwatch.exception.BusinessException;
import com.isu.gaswellwatch.utils.ConverterUtil;
import com.isu.gaswellwatch.vo.CompanyVO;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service("companyService")
@Transactional(rollbackFor = Exception.class)
public class CompanyServiceImpl extends ServiceImpl<CompanyDao, Company> implements CompanyService {

    @Resource
    private SnowflakeConfig snowflakeConfig;

    @Resource
    private CompanyDao companyDao;

    @Override
    public Page<CompanyVO> page(Integer currentPage, Integer pageSize, String name,String code){
        Page<CompanyVO> page = companyDao.page(new Page<>(currentPage, pageSize),name,code);
        return ConverterUtil.convertPage(page,CompanyVO.class);
    }

    @Override
    public void add(CompanyDTO companyDTO){
        //查重
        List<Company> list = list(new LambdaQueryWrapper<Company>().eq(Company::getName, companyDTO.getName()));
        if(CollectionUtil.isNotEmpty(list)) {
            throw new BusinessException("已有相同名称，请重新输入");
        }
        Long companyId = snowflakeConfig.snowflakeId();
        save(Company.builder().id(companyId).name(companyDTO.getName()).description(companyDTO.getDescription()).code(companyDTO.getCode()).build());
    }

    @Override
    public void edit(CompanyEditDTO companyEditDTO){
        List<Company> list = list(new LambdaQueryWrapper<Company>().eq(Company::getName, companyEditDTO.getName()).ne(Company::getId, companyEditDTO.getId()));
        if(CollectionUtil.isNotEmpty(list)) {
            throw new BusinessException("公司名称已存在，请重新输入");
        }
        updateById(ConverterUtil.convert(companyEditDTO, Company.class));
    }

    @Override
    public void delete(Long id){
        //TODO 如果公司绑定了气井  不能删除

        //删除
        removeById(id);
    }

}

